# Frost resistance
rm(list=ls())
repar <- par()
#################################
# loggers first test
test_cond1a <- read.table("BAA61816 2013-03-27 09-52-20.csv", header=T, sep = "\t", encoding ="UTF-8")
test_cond1b <- read.table("BAA61817 2013-03-27 10-01-32.csv", header=T, sep = "\t", encoding ="UTF-8")
# test data first test
frost1 <- read.table("frost_test.csv", header=T, sep = "\t", encoding ="UTF-8")
frost1$perc_dead <- with(frost1, cond1/cond2)
levels(frost1$pop) <- c("F", "J", "L", "T", "V")
frost1$cond <- -15
head(frost1)
# loggers second test
test_cond2a <- read.table("BAA61816 2013-07.csv",  header=T, sep = "\t")
test_cond2b <- read.table("BAA61817 2013-07.csv", header=T, sep = "\t", encoding ="UTF-8")
# test data second test
frost2 <- read.table("frost_test2.csv", header=T, sep = "\t", encoding ="UTF-8")
head(frost2)
levels(frost2$pop)
frost2$altitude <- as.numeric(rep(0,nrow(frost2)))
alt <- c(600, 850, 1000, 2260, 2355)
popi <- c("J", "T", "L", "F", "V")
for(i in 1:5){
  frost2[frost2$pop==popi[i], ]$altitude <- alt[i]
}
frost2$cond <- -7
head(frost2)
# data ready
###################################
# combine data file
head(frost1)
frost <- frost1[,c(1, 5, 6, 3, 4, 7)]
head(frost2[,c(1, 6, 5, 3, 4, 7)])
frost <- rbind(frost, frost2[,c(1, 6, 5, 3, 4, 7)])
frost$dead_bin <- with(frost, cbind(round(cond1), round(cond2-cond1)))
head(frost)
###################################
# analysis
require(car)
model <- glm(dead_bin~cond*pop, data=frost, family=quasibinomial)
Anova(model, type=3, test="F")
model1 <- glm(dead_bin~cond+pop, data=frost, family=quasibinomial)
Anova(model1, type=2, test="F")
require(multcomp)
summary(glht(model1, linfct = mcp(pop="Tukey")), test=adjusted(type="BH"))
############################
# figure
pdf("frost_test1.pdf", width=(15), height=(12))
layout(mat=matrix(c(1, 3, 2,4), 2, 2))
par( mar=c(5.5,6,6,2), mgp=c(4,1,0))
# first test
boxplot(perc_dead~altitude, las=1, ylim=c(0,1), data=frost[frost$cond==-15,], ylab="proportion damaged tissue", las=1, 
        outpch=16, outcex=1.5, cex.axis=2, cex.lab=2, col=c("white", "grey35", "white", "grey35", "white"))
abline(v=3.5)
text(c(3.25, 3.8), c(.04, .03), c("low", "high"), cex=2, col="grey50")
text(.55,.97,"A", cex=3, font=2)
legend("bottomleft", c("group A", "group B"), fill=c("white", "grey35"), cex=2, bty="n")
text(5.2, 0.11, "-15° C", cex=2)
text(5.3, 0.02, "n=8", cex=2)
### test conditions 1
with(test_cond1a[test_cond1a$hours<35 ,] , plot(hours, C, las=1, type="l", cex.lab=2, cex.axis=2,
                                              ylab="temperature (C°)", xlab="time (h)"))
with(test_cond1b[test_cond1b$hours<35 ,], points(hours, C, las=1, pch=16, type="l"))
polygon(c(test_cond1a[test_cond1a$hours<35 ,]$hours, 
          rev(test_cond1b[test_cond1b$hours<35 ,]$hours)), 
        c(test_cond1a[test_cond1a$hours<35 ,]$C, 
          rev(test_cond1b[test_cond1b$hours<35 ,]$C)), 
        col = "grey70", border = NA)
abline(h=-7, lty=3)
abline(h=0, lty=2)
text(35,13.5,"B", cex=3, font=2, adj=1)
### second test
boxplot(perc_dead~altitude, las=1, ylim=c(0,1), 
        data=frost[frost$cond==-7,], ylab="proportion damaged tissue", xlab="altitude", las=1, 
        outpch=16, outcex=1.5, cex.axis=2, cex.lab=2, 
        col=c("white", "grey35", "white", "grey35", "white"))
axis(3, at=c(1,2,3,4,5), labels=c("Juval", "Terz", "Laatsch", "Finail", "Vioz/Coro"), cex.axis=1.8)
abline(v=3.5)
text(c(3.25, 3.8), c(.98, .97), c("low", "high"), cex=2, col="grey50")
#text(5,.95, "-7° C", cex=2)
text(.55,.97,"C", cex=3, font=2)
text(5.25, 0.97, "-7° C", cex=2)
text(5.3, 0.88, "n=5", cex=2)
# test conditions 2
with(test_cond2a[ ,] , plot(hours, C, las=1, type="l", cex.axis=2, xlim=c(0,35), ylim=c(-15,15),
                     ylab="temperature (C°)", xlab="time (h)", cex.lab=2))
with(test_cond2b[, ], points(hours, C, las=1, pch=16, type="l"))

polygon(c(test_cond2a[ ,]$hours, 
          rev(test_cond2b[ ,]$hours)), 
        c(test_cond2a[ ,]$C, 
          rev(test_cond2b[ ,]$C)), 
        col = "grey70", border = NA)
abline(h=-7, lty=3)
abline(h=0, lty=2)
text(35,13.5,"D", cex=3, font=2, adj=1)
par(xpd=NA)
par("usr")
text(-5, 68, "Lowest temperature - 15° C", cex=3)
text(-5, 22, "Lowest temperature - 7° C", cex=3)
dev.off()
#########
par(repar)
##############################################################
##############################################################
# light stress and UVB response
rm(list=ls())
repar <- par()
###############
dat <- read.table("UV2_portion_red1.csv", header=T, sep = "\t", encoding ="UTF-8")

head(dat)

dat$altitude <- as.numeric(rep(0,nrow(dat)))
alt <- c(600, 850, 1000, 2260, 2355)
popi <- c("J", "T", "L", "F", "V")

for(i in 1:5){
  dat[dat$pop==popi[i], ]$altitude <- alt[i]
}
head(dat)
###############
dat$perc_red <- with(dat, (red_area-dead_area)/(total_area))
(vec <- which(dat$perc_red<0))

dat$perc_dead <- with(dat, dead_area/total_area)
###############

#reorder factor levels
levels(dat$treatment) 
dat$treatment2 <- dat$treatment
levels(dat$treatment2) <- c("light_stress", "just_low_light", "low_light_UV") 
levels(dat$treatment2)

##############
########################################################################
# statistics 
require(nlme)
vf1 <- varComb(varIdent(form= ~1|treatment), varIdent(form= ~1|pop))
m <- gls(perc_red~pop*treatment, weights=vf1, data=dat)
anova(m)
summary(m)
plot(m)
names(m)
shapiro.test(resid(m))
qqnorm(resid(m))
############ multcomp
# post hoc after gls
require(multcomp)
interact <- with(droplevels(dat[dat$treatment!="low_light_UV",]), interaction(pop, treatment2))
levels(interact)
## Run the following lines. These introduce methods for 'gls' objects.
##########
model.matrix.gls <- function(object, ...) {
  model.matrix(terms(object), data = getData(object), ...)
}
model.frame.gls <- function(object, ...) {
  model.frame(formula(object), data = getData(object), ...)
}
terms.gls <- function(object, ...) {
  terms(model.frame(object), ...)
}
# red area
interact <- with(droplevels(dat), interaction(pop, treatment2))
m <- gls(perc_red~interact, weights=vf1, data=dat)
b <- summary(glht(m, linfct=mcp(interact= "Tukey")), test = adjusted("BH"))
b
cld(b, level=0.01)

# dead area
m <- gls(perc_dead~pop*treatment, weights=vf1, data=dat)
anova(m)
#
m <- gls(perc_dead~interact, weights=vf1, data=dat)
b <- summary(glht(m, linfct=mcp(interact= "Tukey")), test = adjusted("BH"))
b
cld(b, level=0.01)
#####################################################
# figure
pdf("redarea_uv3a.pdf", width=(10), height=(12))
par(mfrow=c(2,1), cex=1.5,  mar=c(4,4,1,1), mgp=c(2.5,1,0))
bg <- boxplot(perc_red~treatment*altitude, data=dat, las=2, col=c(rep(c("white", "grey60", "grey30"), times=4)), "green", "green", 
              ylab="Proportion red area", xaxt="n", ylim=c(0,1))
axis(1,c(2, 5, 8, 11, 14), sort(unique(dat$altitude)))
abline(v=c(3.5, 6.5, 9.5, 12.5), lty=3)
legend("topright", c("light stress", "low light", "low light + UV"), fill=c("white", "grey50", "grey30"), bg="white")
seqy <- c(1:15)
text(.5, .95, "A", cex=2)
segments(1, 0.83, 1, 0.8)
segments(1, 0.83, 1.4, 0.83)
text(1.75, 0.83, "*", cex=2)
segments(2.1, 0.83, 2.5, 0.83)
segments(2.5, 0.83, 2.5, 0.55)
segments(2, 0.55, 3, 0.55)
#
segments(4, 0.93, 4, 0.9)
segments(4, 0.93, 4.25, 0.93)
text(4.5, 0.93, "*", cex=2)
segments(4.75, 0.93, 5, 0.93)
segments(5, 0.93, 5, 0.75)
segments(5, 0.73, 5.25, 0.73)
text(5.5, 0.73, "*", cex=2)
segments(5.75, 0.73, 6, 0.73)
segments(6, 0.73, 6, 0.25)
#
segments(7, 0.95, 7, 0.93)
segments(7, 0.95, 7.4, 0.95)
text(7.75, 0.95, "*", cex=2)
segments(8.1, 0.95, 8.5, 0.95)
segments(8.5, 0.95, 8.5, 0.57)
segments(8, 0.57, 9, 0.57)
#
segments(10, 0.97, 10, 0.96)
segments(10, 0.97, 10.4, 0.97)
text(10.75, 0.97, "*", cex=2)
segments(11.1, 0.97, 11.5, 0.97)
segments(11.5, 0.97, 11.5, 0.4)
segments(11, 0.4, 12, 0.4)

#
bg <- boxplot(perc_dead~treatment*altitude, data=dat, las=2, col=c(rep(c("white", "grey60", "grey30"), times=4)), "green", "green", 
              ylab="Proportion dead area", xaxt="n", xlab="Altitude", ylim=c(0,1))
axis(3, at=c(2,5,8,11,14), labels=c("Juval", "Terz", "Laatsch", "Finail", "Vioz/Coro"), cex.axis=1.2)
axis(1,c(2, 5, 8, 11, 14), sort(unique(dat$altitude)))
abline(v=c(3.5, 6.5, 9.5, 12.5), lty=3)
text(.5,.95, "B", cex=2)
seqy <- c(1:15)
#
segments(12, 0.22, 12, 0.20)
segments(10.5, 0.22, 11, 0.22)
segments(10.5, 0.22, 10.5, 0.11)
segments(12, 0.22, 11.5, 0.22)
text(11.25, 0.22, "*", cex=2)
segments(10, 0.11, 11, 0.11)
#
segments(13, 0.55, 13, 0.5)
segments(13, 0.55, 13.4, 0.55)
text(13.75, 0.55, "*", cex=2)
segments(14.1, 0.55, 14.5, 0.55)
segments(14.5, 0.55, 14.5, 0.3)
segments(14, 0.3, 15, 0.3)
dev.off()
#####################################################################
# Resistance to high UVB dosages
rm(list=ls())
data <- read.table("UVB_dosage_test.csv", header=T, sep = "\t", encoding ="UTF-8")

bindead <- with(data, cbind(deadperplant, greenperplant))
names(data)
m <- glm(bindead~pop*UV, family=quasibinomial, data=data)
anova(m, test="F")

bindead <- with(data[data$UV==100,], cbind(deadperplant, greenperplant))
m1 <- glm(bindead~pop, family=quasibinomial, data=data[data$UV==100,])
require(multcomp)
cld(summary(glht(m1, linfct=mcp(pop= "Tukey")), test = adjusted("BH")), level=0.05)

# figure
require(sciplot)
data$deadperplant <- data$dead_dryweight/data$plants
data$greenperplant <- data$green_dryweight/data$plants

labname <- c("UV-B dosage (")

pdf("dead_biomass_UV-B_dosage.pdf", width=10, height=6)
par(mfrow=c(1,1), cex=1.5,  mar=c(4,4,1,1), mgp=c(2.5,1,0))
bg <- bargraph.CI(UV, deadperplant/(greenperplant + deadperplant), group=altitude, data=data, legend=T, x.leg=1, 
                  y.leg=.95, ylim=c(0,1), las=1, cex.leg=0.9, xaxt="n", ylab="Proportion dead biomass per plant",
                  xla=expression(paste("UV-B dosage (", kJ~m^{-2}~day^{-1}, ")")),
                  leg.lab=c("  600 Juval", "  850 Terz", "1000 Laatsch", "2260 Finail", "2355 Vioz/Coro"))
text(4.5,.97, "Altitude, Population")
axis(1, c(3.5, 9.5, 15.5, 21.5) , c("0", "2.5", "6.4", "15.2"))
text(c(bg$xvals[1,4], bg$xvals[2,4], bg$xvals[3,4], bg$xvals[4,4], bg$xvals[5,4]),
     c(bg$vals[1,4], bg$vals[2,4], bg$vals[3,4], bg$vals[4,4], bg$vals[5,4])+.1, c("ab", "ab", "b", "a", "b"))
dev.off()

